@@ -158,7 +158,7 @@ extern int ARMCI_Free_local(void *ptr);
 extern int ARMCI_Same_node(int proc);
 
 extern void ARMCI_Finalize();    /* terminate ARMCI */
-extern void ARMCI_Error(char *msg, int code);
+extern void ARMCI_Error(const char *msg, int code);
 extern void ARMCI_Fence(int proc);
 extern void ARMCI_AllFence(void);
 extern int  ARMCI_Rmw(int op, void *ploc, void *prem, int extra, int proc);
