@@ -150,7 +150,7 @@ char *kr_malloc(size_t nbytes, context_t *ctx) {
     size_t nunits;
     char *return_ptr;
 
-#if !((defined(SUN) || defined(SOLARIS)) && !defined(SHMMAX_SEARCH_NO_FORK))
+#if !defined(SHMMAX_SEARCH_NO_FORK)
     if(ctx->ctx_type == KR_CTX_SHMEM) return kr_malloc_shmem(nbytes,ctx);
 #endif
     
@@ -225,7 +225,7 @@ char *kr_malloc(size_t nbytes, context_t *ctx) {
 void kr_free(char *ap, context_t *ctx) {
     Header *bp, *p, **up;
     
-#if !((defined(SUN) || defined(SOLARIS)) && !defined(SHMMAX_SEARCH_NO_FORK))
+#if !defined(SHMMAX_SEARCH_NO_FORK)
     if(ctx->ctx_type == KR_CTX_SHMEM) { kr_free_shmem(ap,ctx); return; }
 #endif
     
