@@ -105,7 +105,7 @@ int comex_initialized()
 }
 
 
-void comex_error(char *msg, int code)
+void comex_error(const char *msg, int code)
 {
     fprintf(stderr,"[%d] Received an Error in Communication: (%d) %s\n",
             l_state.rank, code, msg);
@@ -736,6 +736,11 @@ int comex_malloc(void *ptrs[], size_t size, comex_group_t group)
     return COMEX_SUCCESS;
 }
 
+int comex_malloc_mem_dev(void *ptrs[], size_t size, comex_group_t group,
+        const char* device)
+{
+    return comex_malloc(ptrs,size,group);
+}
 
 int comex_free(void *ptr, comex_group_t group)
 {
@@ -774,6 +779,10 @@ int comex_free(void *ptr, comex_group_t group)
     return COMEX_SUCCESS;
 }
 
+int comex_free_dev(void *ptr, comex_group_t group)
+{
+    return comex_free(ptr, group);
+}
 
 static void acquire_remote_lock(int proc)
 {
