@@ -25,13 +25,15 @@
 #include "ga-wapi.h"
 #include "base.h"
 
+// workaround https://github.com/GlobalArrays/ga/issues/163
+// by using ARMCI_Malloc_local instead of ga_malloc -> MA
+#define GA_TRANSPOSE_USE_ARMCI_MEM 1
+
 #ifdef MSG_COMMS_MPI
 extern ARMCI_Group* ga_get_armci_group_(int);
 #endif
 
 /* work arrays used in all routines */
-static Integer dims[MAXDIM], ld[MAXDIM-1];
-static Integer lo[MAXDIM],hi[MAXDIM];
 static Integer one_arr[MAXDIM]={1,1,1,1,1,1,1};
 
 #define GET_ELEMS(ndim,lo,hi,ld,pelems){\
@@ -60,6 +62,10 @@ void pnga_zero(Integer g_a)
   Integer ndim, type, me, elems, p_handle;
   Integer num_blocks;
   void *ptr;
+  Integer _dims[MAXDIM];
+  Integer _ld[MAXDIM-1];
+  Integer _lo[MAXDIM];
+  Integer _hi[MAXDIM];
   /*register Integer i;*/
   int local_sync_begin,local_sync_end;
 
@@ -72,23 +78,21 @@ void pnga_zero(Integer g_a)
   me = pnga_pgroup_nodeid(p_handle);
 
   pnga_check_handle(g_a, "ga_zero");
-  GA_PUSH_NAME("ga_zero");
 
   num_blocks = pnga_total_blocks(g_a);
 
-  pnga_inquire(g_a, &type, &ndim, dims);
+  pnga_inquire(g_a, &type, &ndim, _dims);
   if (num_blocks < 0) {
-    pnga_distribution(g_a, me, lo, hi);
+    pnga_distribution(g_a, me, _lo, _hi);
 
-    if ( lo[0]> 0 ){ /* base index is 1: we get 0 if no elements stored on p */
+    if ( _lo[0]> 0 ){ /* base index is 1: we get 0 if no elements stored on p */
 
       if (pnga_has_ghosts(g_a)) {
-        pnga_zero_patch(g_a,lo,hi);
-        GA_POP_NAME;
+        pnga_zero_patch(g_a,_lo,_hi);
         return;
       }
-      pnga_access_ptr(g_a, lo, hi, &ptr, ld);
-      GET_ELEMS(ndim,lo,hi,ld,&elems);
+      pnga_access_ptr(g_a, _lo, _hi, &ptr, _ld);
+      GET_ELEMS(ndim,_lo,_hi,_ld,&elems);
 
       /* switch (type){ */
 /*         int *ia; */
@@ -125,7 +129,7 @@ void pnga_zero(Integer g_a)
       memset(ptr, 0, GAsizeofM(type)*elems);
 
       /* release access to the data */
-      pnga_release_update(g_a, lo, hi);
+      pnga_release_update(g_a, _lo, _hi);
     } 
   } else {
     pnga_access_block_segment_ptr(g_a, me, &ptr, &elems);
@@ -167,112 +171,9 @@ void pnga_zero(Integer g_a)
     pnga_release_update_block_segment(g_a, me);
   }
   if(local_sync_end)pnga_pgroup_sync(p_handle);
-  GA_POP_NAME;
 }
 
 
-
-#if 0
-/*\ COPY ONE GLOBAL ARRAY INTO ANOTHER
-\*/
-static void snga_copy_old(Integer g_a, Integer g_b)
-{
-Integer  ndim, ndimb, type, typeb, me, elems=0, elemsb=0;
-Integer dimsb[MAXDIM];
-void *ptr_a, *ptr_b;
-
-   me = pnga_nodeid();
-
-   GA_PUSH_NAME("ga_copy");
-
-   if(g_a == g_b) pnga_error("arrays have to be different ", 0L);
-
-   pnga_inquire(g_a,  &type, &ndim, dims);
-   pnga_inquire(g_b,  &typeb, &ndimb, dimsb);
-
-   if(type != typeb) pnga_error("types not the same", g_b);
-
-   if(!pnga_compare_distr(g_a,g_b))
-
-      pnga_copy_patch("n",g_a, one_arr, dims, g_b, one_arr, dimsb);
-
-   else {
-
-     pnga_sync();
-
-     pnga_distribution(g_a, me, lo, hi);
-     if(lo[0]>0){
-        pnga_access_ptr(g_a, lo, hi, &ptr_a, ld);
-        if (pnga_has_ghosts(g_a)) {
-          GET_ELEMS_W_GHOSTS(ndim,lo,hi,ld,&elems);
-        } else {
-          GET_ELEMS(ndim,lo,hi,ld,&elems);
-        }
-     }
-
-     pnga_distribution(g_b, me, lo, hi);
-     if(lo[0]>0){
-        pnga_access_ptr(g_b, lo, hi, &ptr_b, ld);
-        if (pnga_has_ghosts(g_b)) {
-          GET_ELEMS_W_GHOSTS(ndim,lo,hi,ld,&elems);
-        } else {
-          GET_ELEMS(ndim,lo,hi,ld,&elems);
-        }
-     }
-  
-     if(elems!= elemsb)pnga_error("inconsistent number of elements",elems-elemsb);
-
-     if(elems>0){
-        ARMCI_Copy(ptr_a, ptr_b, (int)elems*GAsizeofM(type));
-        pnga_release(g_a,lo,hi);
-        pnga_release(g_b,lo,hi);
-     }
-
-     pnga_sync();
-   }
-
-   GA_POP_NAME;
-}
-#endif
-
-void printBlock_x(char * banner, Integer type, void *ptr, Integer lo[],
-    Integer hi[], Integer ld[])
-{
-  Integer i,j;
-  Integer offset;
-  printf("p[%d] %s lo[0]: %d hi[0]: %d lo[1]: %d hi[1]: %d\n",
-      pnga_nodeid(),banner,lo[0],hi[0],lo[1],hi[1]);
-  printf("    ");
-  for (i=lo[0]; i<=hi[0]; i++) printf(" %12d",i);
-  printf("\n");
-  for (j=lo[1]; j<=hi[1]; j++) {
-    printf("p[%d] J: %d",pnga_nodeid(),j);
-    for (i=lo[0]; i<=hi[0]; i++) {
-      offset = (j-lo[1])*ld[0] + i-lo[0];
-      switch (type) {
-        case C_FLOAT:
-          printf(" %12.4f",*((float*)ptr+offset));
-          break;
-        case C_DBL:
-          printf(" %12.4f",*((double*)ptr+offset));
-          break;
-        case C_DCPL:
-          printf(" [%12.4f:%12.4f]",*((double*)ptr+2*offset),
-              *((double*)ptr+2*offset+1));
-          break;
-        case C_SCPL:
-          printf(" [%12.4f:%12.4f]",*((float*)ptr+2*offset),
-              *((float*)ptr+2*offset+1));
-          break;
-        default:
-          pnga_error("ga_matmul_basic: wrong data type", type);
-      }
-    }
-    printf("\n");
-  }
-  printf("\n\n");
-}
-
 /*\ COPY ONE GLOBAL ARRAY INTO ANOTHER
 \*/
 #if HAVE_SYS_WEAK_ALIAS_PRAGMA
@@ -289,8 +190,11 @@ char *ptr_a, *ptr_b;
 int local_sync_begin,local_sync_end,use_put;
 _iterator_hdl hdl;
 
-   GA_PUSH_NAME("ga_copy");
 
+   Integer _dims[MAXDIM];
+   Integer _ld[MAXDIM-1];
+   Integer _lo[MAXDIM];
+   Integer _hi[MAXDIM];
    local_sync_begin = _ga_sync_begin; local_sync_end = _ga_sync_end;
    _ga_sync_begin = 1; _ga_sync_end=1; /*remove any previous masking*/
    a_grp = pnga_get_pgroup(g_a);
@@ -321,13 +225,13 @@ _iterator_hdl hdl;
 
    if(g_a == g_b) pnga_error("arrays have to be different ", 0L);
 
-   pnga_inquire(g_a,  &type, &ndim, dims);
+   pnga_inquire(g_a,  &type, &ndim, _dims);
    pnga_inquire(g_b,  &typeb, &ndimb, dimsb);
 
    if(type != typeb) pnga_error("types not the same", g_b);
    if(ndim != ndimb) pnga_error("dimensions not the same", ndimb);
 
-   for(i=0; i< ndim; i++)if(dims[i]!=dimsb[i]) 
+   for(i=0; i< ndim; i++)if(_dims[i]!=dimsb[i]) 
                           pnga_error("dimensions not the same",i);
 
    if ((pnga_is_mirrored(g_a) && pnga_is_mirrored(g_b)) ||
@@ -338,18 +242,18 @@ _iterator_hdl hdl;
      if (use_put) {
 #if 0
        if (num_blocks_a < 0) {
-         pnga_distribution(g_a, me_a, lo, hi);
-         if(lo[0]>0){
-           pnga_access_ptr(g_a, lo, hi, &ptr_a, ld);
-           pnga_put(g_b, lo, hi, ptr_a, ld);
+         pnga_distribution(g_a, me_a, _lo, _hi);
+         if(_lo[0]>0){
+           pnga_access_ptr(g_a, _lo, _hi, &ptr_a, _ld);
+           pnga_put(g_b, _lo, _hi, ptr_a, _ld);
          }
        } else {
          if (!pnga_uses_proc_grid(g_a)) {
            for (i=me_a; i<num_blocks_a; i += anproc) {
-             pnga_distribution(g_a, i, lo, hi);
-             if (lo[0]>0) {
-               pnga_access_block_ptr(g_a, i, &ptr_a, ld);
-               pnga_put(g_b, lo, hi, ptr_a, ld);
+             pnga_distribution(g_a, i, _lo, _hi);
+             if (_lo[0]>0) {
+               pnga_access_block_ptr(g_a, i, &ptr_a, _ld);
+               pnga_put(g_b, _lo, _hi, ptr_a, _ld);
              }
            }
          } else {
@@ -363,14 +267,14 @@ _iterator_hdl hdl;
              /* find bounding coordinates of block */
              chk = 1;
              for (i = 0; i < ndim; i++) {
-               lo[i] = index[i]*block_dims[i]+1;
-               hi[i] = (index[i] + 1)*block_dims[i];
-               if (hi[i] > dims[i]) hi[i] = dims[i];
-               if (hi[i] < lo[i]) chk = 0;
+               _lo[i] = index[i]*block_dims[i]+1;
+               _hi[i] = (index[i] + 1)*block_dims[i];
+               if (_hi[i] > _dims[i]) _hi[i] = _dims[i];
+               if (_hi[i] < _lo[i]) chk = 0;
              }
              if (chk) {
-               pnga_access_block_grid_ptr(g_a, index, &ptr_a, ld);
-               pnga_put(g_b, lo, hi, ptr_a, ld);
+               pnga_access_block_grid_ptr(g_a, index, &ptr_a, _ld);
+               pnga_put(g_b, _lo, _hi, ptr_a, _ld);
              }
              /* increment index to get next block on processor */
              index[0] += topology[0];
@@ -385,25 +289,25 @@ _iterator_hdl hdl;
        }
 #else
        pnga_local_iterator_init(g_a, &hdl);
-       while (pnga_local_iterator_next(&hdl,lo,hi,&ptr_a,ld)) {
-         pnga_put(g_b, lo, hi, ptr_a, ld);
+       while (pnga_local_iterator_next(&hdl,_lo,_hi,&ptr_a,_ld)) {
+         pnga_put(g_b, _lo, _hi, ptr_a, _ld);
        }
 #endif
      } else {
 #if 0
        if (num_blocks_b < 0) {
-         pnga_distribution(g_b, me_b, lo, hi);
-         if(lo[0]>0){
-           pnga_access_ptr(g_b, lo, hi, &ptr_b, ld);
-           pnga_get(g_a, lo, hi, ptr_b, ld);
+         pnga_distribution(g_b, me_b, _lo, _hi);
+         if(_lo[0]>0){
+           pnga_access_ptr(g_b, _lo, _hi, &ptr_b, _ld);
+           pnga_get(g_a, _lo, _hi, ptr_b, _ld);
          }
        } else {
          if (!pnga_uses_proc_grid(g_a)) {
            for (i=me_b; i<num_blocks_b; i += bnproc) {
-             pnga_distribution(g_b, i, lo, hi);
-             if (lo[0]>0) {
-               pnga_access_block_ptr(g_b, i, &ptr_b, ld);
-               pnga_get(g_a, lo, hi, ptr_b, ld);
+             pnga_distribution(g_b, i, _lo, _hi);
+             if (_lo[0]>0) {
+               pnga_access_block_ptr(g_b, i, &ptr_b, _ld);
+               pnga_get(g_a, _lo, _hi, ptr_b, _ld);
              }
            }
          } else {
@@ -417,14 +321,14 @@ _iterator_hdl hdl;
              /* find bounding coordinates of block */
              chk = 1;
              for (i = 0; i < ndim; i++) {
-               lo[i] = index[i]*block_dims[i]+1;
-               hi[i] = (index[i] + 1)*block_dims[i];
-               if (hi[i] > dims[i]) hi[i] = dims[i];
-               if (hi[i] < lo[i]) chk = 0;
+               _lo[i] = index[i]*block_dims[i]+1;
+               _hi[i] = (index[i] + 1)*block_dims[i];
+               if (_hi[i] > _dims[i]) _hi[i] = _dims[i];
+               if (_hi[i] < _lo[i]) chk = 0;
              }
              if (chk) {
-               pnga_access_block_grid_ptr(g_b, index, &ptr_b, ld);
-               pnga_get(g_a, lo, hi, ptr_b, ld);
+               pnga_access_block_grid_ptr(g_b, index, &ptr_b, _ld);
+               pnga_get(g_a, _lo, _hi, ptr_b, _ld);
              }
              /* increment index to get next block on processor */
              index[0] += topology[0];
@@ -439,8 +343,8 @@ _iterator_hdl hdl;
        }
 #else
        pnga_local_iterator_init(g_b, &hdl);
-       while (pnga_local_iterator_next(&hdl,lo,hi,&ptr_b,ld)) {
-         pnga_get(g_a, lo, hi, ptr_b, ld);
+       while (pnga_local_iterator_next(&hdl,_lo,_hi,&ptr_b,_ld)) {
+         pnga_get(g_a, _lo, _hi, ptr_b, _ld);
        }
 #endif
      }
@@ -449,19 +353,19 @@ _iterator_hdl hdl;
      if (pnga_is_mirrored(g_a)) {
        /* Source array is mirrored and destination
           array is distributed. Assume source array is consistent */
-       pnga_distribution(g_b, me_b, lo, hi);
-       if (lo[0]>0) {
-         pnga_access_ptr(g_b, lo, hi, &ptr_b, ld);
-         pnga_get(g_a, lo, hi, ptr_b, ld);
+       pnga_distribution(g_b, me_b, _lo, _hi);
+       if (_lo[0]>0) {
+         pnga_access_ptr(g_b, _lo, _hi, &ptr_b, _ld);
+         pnga_get(g_a, _lo, _hi, ptr_b, _ld);
        } 
      } else {
        /* source array is distributed and destination
           array is mirrored */
        pnga_zero(g_b);
-       pnga_distribution(g_a, me_a, lo, hi);
-       if (lo[0] > 0) {
-         pnga_access_ptr(g_a, lo, hi, &ptr_a, ld);
-         pnga_put(g_b, lo, hi, ptr_a, ld);
+       pnga_distribution(g_a, me_a, _lo, _hi);
+       if (_lo[0] > 0) {
+         pnga_access_ptr(g_a, _lo, _hi, &ptr_a, _ld);
+         pnga_put(g_b, _lo, _hi, ptr_a, _ld);
        }
        pnga_merge_mirrored(g_b);
      }
@@ -477,7 +381,6 @@ _iterator_hdl hdl;
        pnga_pgroup_sync(b_grp);
      }
    }
-   GA_POP_NAME;
 }
 
 
@@ -502,12 +405,15 @@ int alen=0;
 Integer a_grp=0, b_grp=0;
 Integer num_blocks_a=0, num_blocks_b=0;
 
+Integer _dims[MAXDIM];
+Integer _ld[MAXDIM-1];
+Integer _lo[MAXDIM];
+Integer _hi[MAXDIM];
 Integer andim, adims[MAXDIM];
 Integer bndim, bdims[MAXDIM];
 
    _ga_sync_begin = 1; _ga_sync_end=1; /*remove any previous masking*/
 
-   GA_PUSH_NAME("ga_dot");
    a_grp = pnga_get_pgroup(g_a);
    b_grp = pnga_get_pgroup(g_b);
    if (a_grp != b_grp)
@@ -522,7 +428,6 @@ Integer bndim, bdims[MAXDIM];
      pnga_inquire(g_b, &type, &bndim, bdims);
      pnga_dot_patch(g_a, "n", one_arr, adims, g_b, "n", one_arr, bdims,
          value);
-     GA_POP_NAME;
      return;
    }
 
@@ -535,20 +440,19 @@ Integer bndim, bdims[MAXDIM];
        pnga_dot_patch(g_a, "n", one_arr, adims, g_b, "n", one_arr, bdims,
                       value);
        
-       GA_POP_NAME;
        return;
    }
    
    pnga_pgroup_sync(a_grp);
-   pnga_inquire(g_a,  &type, &ndim, dims);
+   pnga_inquire(g_a,  &type, &ndim, _dims);
    if(type != Type) pnga_error("type not correct", g_a);
-   pnga_distribution(g_a, me, lo, hi);
-   if(lo[0]>0){
-      pnga_access_ptr(g_a, lo, hi, &ptr_a, ld);
+   pnga_distribution(g_a, me, _lo, _hi);
+   if(_lo[0]>0){
+      pnga_access_ptr(g_a, _lo, _hi, &ptr_a, _ld);
       if (pnga_has_ghosts(g_a)) {
-        GET_ELEMS_W_GHOSTS(ndim,lo,hi,ld,&elems);
+        GET_ELEMS_W_GHOSTS(ndim,_lo,_hi,_ld,&elems);
       } else {
-        GET_ELEMS(ndim,lo,hi,ld,&elems);
+        GET_ELEMS(ndim,_lo,_hi,_ld,&elems);
       }
    }
 
@@ -556,15 +460,15 @@ Integer bndim, bdims[MAXDIM];
      elemsb = elems;
      ptr_b = ptr_a;
    }else {  
-     pnga_inquire(g_b,  &type, &ndim, dims);
+     pnga_inquire(g_b,  &type, &ndim, _dims);
      if(type != Type) pnga_error("type not correct", g_b);
-     pnga_distribution(g_b, me, lo, hi);
-     if(lo[0]>0){
-        pnga_access_ptr(g_b, lo, hi, &ptr_b, ld);
+     pnga_distribution(g_b, me, _lo, _hi);
+     if(_lo[0]>0){
+        pnga_access_ptr(g_b, _lo, _hi, &ptr_b, _ld);
         if (pnga_has_ghosts(g_b)) {
-          GET_ELEMS_W_GHOSTS(ndim,lo,hi,ld,&elemsb);
+          GET_ELEMS_W_GHOSTS(ndim,_lo,_hi,_ld,&elemsb);
         } else {
-          GET_ELEMS(ndim,lo,hi,ld,&elemsb);
+          GET_ELEMS(ndim,_lo,_hi,_ld,&elemsb);
         }
      }
    }
@@ -654,8 +558,8 @@ Integer bndim, bdims[MAXDIM];
    
       /* release access to the data */
       if(elems>0){
-         pnga_release(g_a, lo, hi);
-         if(g_a != g_b)pnga_release(g_b, lo, hi);
+         pnga_release(g_a, _lo, _hi);
+         if(g_a != g_b)pnga_release(g_b, _lo, _hi);
       }
 
     /*convert from C data type to ARMCI type */
@@ -683,7 +587,6 @@ Integer bndim, bdims[MAXDIM];
      }
    }
     
-   GA_POP_NAME;
 
 }
 
@@ -698,6 +601,10 @@ void pnga_scale(Integer g_a, void* alpha)
   Integer num_blocks;
   void *ptr;
   int local_sync_begin,local_sync_end;
+  Integer _dims[MAXDIM];
+  Integer _ld[MAXDIM-1];
+  Integer _lo[MAXDIM];
+  Integer _hi[MAXDIM];
 
   local_sync_begin = _ga_sync_begin; local_sync_end = _ga_sync_end;
   _ga_sync_begin = 1; _ga_sync_end=1; /*remove any previous masking*/
@@ -707,21 +614,20 @@ void pnga_scale(Integer g_a, void* alpha)
   me = pnga_pgroup_nodeid(grp_id);
 
   pnga_check_handle(g_a, "ga_scale");
-  GA_PUSH_NAME("ga_scale");
   num_blocks = pnga_total_blocks(g_a);
 
-  pnga_inquire(g_a, &type, &ndim, dims);
+  pnga_inquire(g_a, &type, &ndim, _dims);
   if (num_blocks < 0) {
-    pnga_distribution(g_a, me, lo, hi);
+    pnga_distribution(g_a, me, _lo, _hi);
     if (pnga_has_ghosts(g_a)) {
-      pnga_scale_patch(g_a, lo, hi, alpha);
+      pnga_scale_patch(g_a, _lo, _hi, alpha);
       return;
     }
 
-    if ( lo[0]> 0 ){ /* base index is 1: we get 0 if no elements stored on p */
+    if ( _lo[0]> 0 ){ /* base index is 1: we get 0 if no elements stored on p */
 
-      pnga_access_ptr(g_a, lo, hi, &ptr, ld);
-      GET_ELEMS(ndim,lo,hi,ld,&elems);
+      pnga_access_ptr(g_a, _lo, _hi, &ptr, _ld);
+      GET_ELEMS(ndim,_lo,_hi,_ld,&elems);
 
       switch (type){
         int *ia;
@@ -773,7 +679,7 @@ void pnga_scale(Integer g_a, void* alpha)
       }
 
       /* release access to the data */
-      pnga_release_update(g_a, lo, hi);
+      pnga_release_update(g_a, _lo, _hi);
     }
   } else {
     pnga_access_block_segment_ptr(g_a, me, &ptr, &elems);
@@ -828,7 +734,6 @@ void pnga_scale(Integer g_a, void* alpha)
     /* release access to the data */
     pnga_release_update_block_segment(g_a, me);
   }
-  GA_POP_NAME;
   if(local_sync_end)pnga_pgroup_sync(grp_id); 
 }
 
@@ -843,7 +748,11 @@ register Integer i;
 void *ptr_a, *ptr_b, *ptr_c;
 Integer a_grp, b_grp, c_grp;
 int local_sync_begin,local_sync_end;
-
+ 
+ Integer _dims[MAXDIM];
+ Integer _ld[MAXDIM-1];
+ Integer _lo[MAXDIM];
+ Integer _hi[MAXDIM];
  Integer andim, adims[MAXDIM];
  Integer bndim, bdims[MAXDIM];
  Integer cndim, cdims[MAXDIM];
@@ -851,7 +760,6 @@ int local_sync_begin,local_sync_end;
    local_sync_begin = _ga_sync_begin; local_sync_end = _ga_sync_end;
    _ga_sync_begin = 1; _ga_sync_end=1; /*remove any previous masking*/
 
-   GA_PUSH_NAME("ga_add");
    a_grp = pnga_get_pgroup(g_a);
    b_grp = pnga_get_pgroup(g_b);
    c_grp = pnga_get_pgroup(g_c);
@@ -874,28 +782,27 @@ int local_sync_begin,local_sync_end;
        pnga_add_patch(alpha, g_a, one_arr, adims, beta, g_b, one_arr, bdims,
                       g_c, one_arr, cdims);
        
-       GA_POP_NAME;
        return;
    }
 
    pnga_pgroup_sync(a_grp);
-   pnga_inquire(g_c,  &typeC, &ndim, dims);
-   pnga_distribution(g_c, me, lo, hi);
-   if (  lo[0]>0 ){
-     pnga_access_ptr(g_c, lo, hi, &ptr_c, ld);
-     GET_ELEMS(ndim,lo,hi,ld,&elems);
+   pnga_inquire(g_c,  &typeC, &ndim, _dims);
+   pnga_distribution(g_c, me, _lo, _hi);
+   if (  _lo[0]>0 ){
+     pnga_access_ptr(g_c, _lo, _hi, &ptr_c, _ld);
+     GET_ELEMS(ndim,_lo,_hi,_ld,&elems);
    }
 
    if(g_a == g_c){
      ptr_a  = ptr_c;
      elemsa = elems;
    }else { 
-     pnga_inquire(g_a,  &type, &ndim, dims);
+     pnga_inquire(g_a,  &type, &ndim, _dims);
      if(type != typeC) pnga_error("types not consistent", g_a);
-     pnga_distribution(g_a, me, lo, hi);
-     if (  lo[0]>0 ){
-       pnga_access_ptr(g_a, lo, hi, &ptr_a, ld);
-       GET_ELEMS(ndim,lo,hi,ld,&elemsa);
+     pnga_distribution(g_a, me, _lo, _hi);
+     if (  _lo[0]>0 ){
+       pnga_access_ptr(g_a, _lo, _hi, &ptr_a, _ld);
+       GET_ELEMS(ndim,_lo,_hi,_ld,&elemsa);
      }
    }
 
@@ -903,19 +810,19 @@ int local_sync_begin,local_sync_end;
      ptr_b  = ptr_c;
      elemsb = elems;
    }else {
-     pnga_inquire(g_b,  &type, &ndim, dims);
+     pnga_inquire(g_b,  &type, &ndim, _dims);
      if(type != typeC) pnga_error("types not consistent", g_b);
-     pnga_distribution(g_b, me, lo, hi);
-     if (  lo[0]>0 ){
-       pnga_access_ptr(g_b, lo, hi, &ptr_b, ld);
-       GET_ELEMS(ndim,lo,hi,ld,&elemsb);
+     pnga_distribution(g_b, me, _lo, _hi);
+     if (  _lo[0]>0 ){
+       pnga_access_ptr(g_b, _lo, _hi, &ptr_b, _ld);
+       GET_ELEMS(ndim,_lo,_hi,_ld,&elemsb);
      }
    }
 
    if(elems!= elemsb)pnga_error("inconsistent number of elements a",elems-elemsb);
    if(elems!= elemsa)pnga_error("inconsistent number of elements b",elems-elemsa);
 
-   if (  lo[0]>0 ){
+   if (  _lo[0]>0 ){
 
        /* operation on the "local" piece of data */
        switch(type){
@@ -992,13 +899,12 @@ int local_sync_begin,local_sync_end;
        }
 
        /* release access to the data */
-       pnga_release_update(g_c, lo, hi);
-       if(g_c != g_a)pnga_release(g_a, lo, hi);
-       if(g_c != g_b)pnga_release(g_b, lo, hi);
+       pnga_release_update(g_c, _lo, _hi);
+       if(g_c != g_a)pnga_release(g_a, _lo, _hi);
+       if(g_c != g_b)pnga_release(g_b, _lo, _hi);
    }
 
 
-   GA_POP_NAME;
    if(local_sync_end)pnga_pgroup_sync(a_grp);
 }
 
@@ -1006,7 +912,7 @@ int local_sync_begin,local_sync_end;
 static 
 void snga_local_transpose(Integer type, char *ptra, Integer n, Integer stride, char *ptrb)
 {
-int i;
+Integer i;
     switch(type){
 
        case C_INT:
@@ -1048,6 +954,7 @@ int i;
 void pnga_transpose(Integer g_a, Integer g_b)
 {
 Integer me = pnga_nodeid();
+Integer _ld[MAXDIM-1];
 Integer nproc = pnga_nnodes(); 
 Integer atype, btype, andim, adims[MAXDIM], bndim, bdims[MAXDIM];
 Integer lo[2],hi[2],ld[2];
@@ -1056,7 +963,6 @@ Integer num_blocks_a;
 char *ptr_tmp, *ptr_a;
 _iterator_hdl hdl;
 
-    GA_PUSH_NAME("ga_transpose");
     
     local_sync_begin = _ga_sync_begin; local_sync_end = _ga_sync_end;
     _ga_sync_begin = 1; _ga_sync_end=1; /*remove any previous masking*/
@@ -1079,7 +985,14 @@ _iterator_hdl hdl;
       int i, size=GAsizeofM(atype);
 
       nelem = (hi[0]-lo[0]+1)*(hi[1]-lo[1]+1);
-      ptr_tmp = (char *) ga_malloc(nelem, atype, "transpose_tmp");
+#ifdef GA_TRANSPOSE_USE_ARMCI_MEM
+{
+      size_t bytes = nelem * size;
+      ptr_tmp = ARMCI_Malloc_local(bytes);
+}
+#else
+      ptr_tmp = (char *) pnga_malloc(nelem, atype, "transpose_tmp");
+#endif
 
       nrow   = hi[0] -lo[0]+1;
       ncol   = hi[1] -lo[1]+1; 
@@ -1093,7 +1006,11 @@ _iterator_hdl hdl;
         ptr_a += ld[0]*size;
       }
       pnga_put(g_b, lob, hib, ptr_tmp ,&ncol);
-      ga_free(ptr_tmp);
+#ifdef GA_TRANSPOSE_USE_ARMCI_MEM
+      ARMCI_Free_local(ptr_tmp);
+#else
+      pnga_free(ptr_tmp);
+#endif
     }
 #else
     num_blocks_a = pnga_total_blocks(g_a);
@@ -1115,13 +1032,13 @@ _iterator_hdl hdl;
         ptr_tmp = (char *) ga_malloc(nelem, atype, "transpose_tmp");
 
         /* get access to local data */
-        pnga_access_ptr(g_a, lo, hi, &ptr_a, ld);
+        pnga_access_ptr(g_a, lo, hi, &ptr_a, _ld);
 
         for(i = 0; i < ncol; i++){
           char *ptr = ptr_tmp + i*size;
 
           snga_local_transpose(atype, ptr_a, nrow, ncol*size, ptr);
-          ptr_a += ld[0]*size;
+          ptr_a += _ld[0]*size;
         }
 
         pnga_release(g_a, lo, hi); 
@@ -1145,7 +1062,7 @@ _iterator_hdl hdl;
       if (!pnga_uses_proc_grid(g_a)) {
         for (idx = me; idx < num_blocks_a; idx += nproc) {
           pnga_distribution(g_a, idx, lo, hi);
-          pnga_access_block_ptr(g_a, idx, &ptr_a, ld);
+          pnga_access_block_ptr(g_a, idx, &ptr_a, _ld);
 
           nrow   = hi[0] -lo[0]+1;
           ncol   = hi[1] -lo[1]+1; 
@@ -1156,7 +1073,7 @@ _iterator_hdl hdl;
             char *ptr = ptr_tmp + i*size;
 
             snga_local_transpose(atype, ptr_a, nrow, ncol*size, ptr);
-            ptr_a += ld[0]*size;
+            ptr_a += _ld[0]*size;
           }
           pnga_put(g_b, lob, hib, ptr_tmp ,&ncol);
 
@@ -1181,7 +1098,7 @@ _iterator_hdl hdl;
         }
 
         if (ichk) {
-          pnga_access_block_grid_ptr(g_a, index, &ptr_a, ld);
+          pnga_access_block_grid_ptr(g_a, index, &ptr_a, _ld);
           while (index[andim-1] < blocks[andim-1]) {
             /* find bounding coordinates of block */
             chk = 1;
@@ -1192,7 +1109,7 @@ _iterator_hdl hdl;
               if (hi[i] < lo[i]) chk = 0;
             }
             if (chk) {
-              pnga_access_block_grid_ptr(g_a, index, &ptr_a, ld);
+              pnga_access_block_grid_ptr(g_a, index, &ptr_a, _ld);
               nrow   = hi[0] -lo[0]+1;
               ncol   = hi[1] -lo[1]+1; 
               nelem  = nrow*ncol;
@@ -1201,7 +1118,7 @@ _iterator_hdl hdl;
               for(i = 0; i < ncol; i++){
                 char *ptr = ptr_tmp + i*size;
                 snga_local_transpose(atype, ptr_a, nrow, block_dims[0]*size, ptr);
-                ptr_a += ld[0]*size;
+                ptr_a += _ld[0]*size;
               }
               pnga_put(g_b, lob, hib, ptr_tmp ,&block_dims[0]);
               pnga_release_update_block_grid(g_a, index);
@@ -1221,5 +1138,4 @@ _iterator_hdl hdl;
     }
 #endif
     if(local_sync_end)pnga_sync();
-    GA_POP_NAME;
 }
