@@ -1161,7 +1161,7 @@ static void check_result(cond, transa, transb, alpha, beta, atype,
 
        m_t=m; n_t=n; k_t=k;
        adim_t=adim; bdim_t=bdim; cdim_t=cdim;
-#if (defined(CRAY) || defined(WIN32)) && !NOFORT
+#if defined(WIN32) && !NOFORT
        pnga_error("check_result: Serial dgemms not defined", 0L);
 #else
        switch(atype) {
@@ -1405,9 +1405,6 @@ void pnga_matmul(transa, transb, alpha, beta,
 	  CONTIG_CHUNKS_OPT_FLAG = UNSET;
 	  DIRECT_ACCESS_OPT_FLAG = UNSET;
        }
-#    if defined(__crayx1) || defined(NEC)
-       use_NB_matmul = UNSET;
-#    endif
     }
 
     /* if block cyclic, then use regular algorithm. This is turned on for now
@@ -1497,8 +1494,8 @@ void pnga_matmul(transa, transb, alpha, beta,
 	  }
 
 	  if(tmp == NULL) { /*if armci malloc fails again, then get from MA */
-	     tmp = a_ar[0] = a =(DoubleComplex*) ga_malloc(elems,atype,
-							   "GA mulmat bufs");
+	     tmp = a_ar[0] = a =(DoubleComplex*) pnga_malloc(elems,atype,
+                                                      "GA mulmat bufs");
 	  }
 
 	  if(use_NB_matmul) tmp = a_ar[1] = a_ar[0] + (Ichunk*Kchunk)/factor+1;
@@ -1561,7 +1558,9 @@ void pnga_matmul(transa, transb, alpha, beta,
 	     
        a = a_ar[0];
        if(use_armci_memory == SET) ARMCI_Free_local(a);
-       else ga_free(a);
+       else {
+         pnga_free(a);
+       }
        
 #if DEBUG_
        Integer grp_me;
@@ -1728,7 +1727,7 @@ Integer clo[2], chi[2];
      else /* "EXTRA" elems for safety - just in case */
        elems = 3*Ichunk*Jchunk + EXTRA*factor;
      
-     a = (DoubleComplex*) ga_malloc(elems, atype, "GA mulmat bufs");
+     a = (DoubleComplex*) pnga_malloc(elems, atype, "GA mulmat bufs");
      b = a + (Ichunk*Kchunk)/factor + 1; 
      c = b + (Kchunk*Jchunk)/factor + 1;
    }
@@ -1877,7 +1876,7 @@ Integer clo[2], chi[2];
    }
    
 #ifndef STATBUF
-   ga_free(a);
+   pnga_free(a);
 #endif
 
    if(local_sync_end)pnga_sync();
@@ -2224,7 +2223,7 @@ BlasInt idim_t, jdim_t, kdim_t, adim_t, bdim_t, cdim_t;
      else /* "EXTRA" elems for safety - just in case */
        elems = 3*Ichunk*Jchunk + EXTRA*factor;
 
-     a = (DoubleComplex*) ga_malloc(elems, atype, "GA mulmat bufs");     
+     a = (DoubleComplex*) pnga_malloc(elems, atype, "GA mulmat bufs");     
      b = a + (Ichunk*Kchunk)/factor + 1; 
      c = b + (Kchunk*Jchunk)/factor + 1;
    }
@@ -2363,7 +2362,7 @@ BlasInt idim_t, jdim_t, kdim_t, adim_t, bdim_t, cdim_t;
    }
 
 #ifndef STATBUF
-   ga_free(a);
+   pnga_free(a);
 #endif
    
    if(local_sync_end)pnga_sync(); 
