@@ -322,7 +322,6 @@ void pnga_median_patch(
   _ga_sync_begin = 1; _ga_sync_end=1; /*remove any previous masking*/
   if(local_sync_begin)pnga_sync();
 
-  GA_PUSH_NAME ("pnga_median_patch");
 
   pnga_inquire (g_a, &atype, &andim, adims);
   pnga_inquire (g_b, &btype, &bndim, bdims);
@@ -679,7 +678,6 @@ void pnga_median_patch(
     pnga_destroy (g_B);
   if (c_temp_created)
     pnga_destroy (g_C);
-  GA_POP_NAME;
   if(local_sync_end)pnga_sync();
 }
 
@@ -899,7 +897,6 @@ void pnga_norm_infinity(Integer g_a, double *nm)
   if(local_sync_begin)pnga_sync();
 
   pnga_check_handle (g_a, "ga_norm_infinity_");
-  GA_PUSH_NAME ("ga_norm_infinity_");
 
   pnga_inquire (g_a, &type, &ndim, dims);
 
@@ -1048,7 +1045,6 @@ void pnga_norm_infinity(Integer g_a, double *nm)
       pnga_error("ga_norm_infinity_:wrong data type.", type);
   }
 
-  GA_POP_NAME;
   if (local_sync_end)pnga_sync();
 }
 
@@ -1212,7 +1208,6 @@ void pnga_norm1(Integer g_a, double *nm)
   if(local_sync_begin)pnga_sync();
 
   pnga_check_handle (g_a, "ga_norm1_");
-  GA_PUSH_NAME ("ga_norm1_");
 
   pnga_inquire (g_a, &type, &ndim, dims);
 
@@ -1358,7 +1353,6 @@ void pnga_norm1(Integer g_a, double *nm)
       pnga_error("ga_norm1_:wrong data type.", type);
   }
 
-  GA_POP_NAME;
   if(local_sync_end)pnga_sync();
 }
 
@@ -1502,7 +1496,6 @@ void pnga_get_diag(Integer g_a, Integer g_v)
 
   pnga_check_handle (g_a, "ga_get_diag_");
   pnga_check_handle (g_v, "ga_get_diag_");
-  GA_PUSH_NAME ("ga_get_diag_");
 
   pnga_inquire (g_a, &atype, &andim, adims);
   dim1 = adims[0];
@@ -1588,7 +1581,6 @@ void pnga_get_diag(Integer g_a, Integer g_v)
   }
 #endif
 
-  GA_POP_NAME;
   if(local_sync_end)pnga_sync();
 }
 
@@ -1731,7 +1723,6 @@ void pnga_add_diagonal(Integer g_a, Integer g_v)
 
   pnga_check_handle (g_a, "ga_add_diagonal_");
   pnga_check_handle (g_v, "ga_add_diagonal_");
-  GA_PUSH_NAME ("ga_add_diagonal_");
 
   pnga_inquire(g_a, &atype, &andim, adims);
   dim1 = adims[0];
@@ -1816,7 +1807,6 @@ void pnga_add_diagonal(Integer g_a, Integer g_v)
     }
   }
 #endif
-  GA_POP_NAME;
   if(local_sync_end)pnga_sync();
 }
 
@@ -1963,7 +1953,6 @@ void pnga_set_diagonal(Integer g_a, Integer g_v)
 
   pnga_check_handle (g_a, "ga_set_diagonal_");
   pnga_check_handle (g_v, "ga_set_diagonal_");
-  GA_PUSH_NAME ("ga_set_diagonal_");
 
   pnga_inquire (g_a, &atype, &andim, adims);
   dim1 = adims[0];
@@ -2050,7 +2039,6 @@ void pnga_set_diagonal(Integer g_a, Integer g_v)
 
   }
 #endif
-  GA_POP_NAME;
   if(local_sync_end)pnga_sync();
 }
 
@@ -2166,7 +2154,6 @@ void pnga_shift_diagonal(Integer g_a, void *c)
   if(local_sync_begin)pnga_sync();
 
   pnga_check_handle (g_a, "ga_shift_diagonal_");
-  GA_PUSH_NAME ("ga_shift_diagonal_");
 
   pnga_inquire (g_a, &atype, &andim, adims);
   /*dim1 = adims[0];*/
@@ -2234,7 +2221,6 @@ void pnga_shift_diagonal(Integer g_a, void *c)
     }
   }
 #endif
-  GA_POP_NAME;
   if(local_sync_end)pnga_sync();
 }
 
@@ -2317,7 +2303,6 @@ void pnga_zero_diagonal(Integer g_a)
   _ga_sync_begin = 1; _ga_sync_end=1; /*remove any previous masking*/
   if(local_sync_begin)pnga_sync();
 
-  GA_PUSH_NAME ("ga_zero_diagonal_");
 
   pnga_inquire (g_a, &atype, &andim, adims);
   /*dim1 = adims[0];*/
@@ -2438,7 +2423,6 @@ void pnga_zero_diagonal(Integer g_a)
     }
   }
 #endif
-  GA_POP_NAME;
   if(local_sync_end)pnga_sync();
 }
 
@@ -2549,7 +2533,6 @@ void pnga_scale_rows(Integer g_a, Integer g_v)
 
   pnga_check_handle (g_a, "ga_scale_rows_");
   pnga_check_handle (g_v, "ga_scale_rows_");
-  GA_PUSH_NAME ("ga_scale_rows_");
 
   pnga_inquire (g_a, &atype, &andim, adims);
   dim1 = adims[0];
@@ -2646,7 +2629,6 @@ void pnga_scale_rows(Integer g_a, Integer g_v)
     }
   }
 #endif
-  GA_POP_NAME;
   if(local_sync_end)pnga_sync();
 }
 
@@ -2758,7 +2740,6 @@ void pnga_scale_cols(Integer g_a, Integer g_v)
 
   pnga_check_handle (g_a, "ga_scale_cols_");
   pnga_check_handle (g_v, "ga_scale_cols_");
-  GA_PUSH_NAME ("ga_scale_cols_");
 
   pnga_inquire(g_a, &atype, &andim, adims);
   /*dim1 = adims[0];*/
@@ -2855,6 +2836,5 @@ void pnga_scale_cols(Integer g_a, Integer g_v)
     }
   }
 #endif
-  GA_POP_NAME;
   if(local_sync_end)pnga_sync();
 }
